summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorLoic Guegan <manzerberdes@gmx.com>2019-05-26 15:52:46 +0200
committerLoic Guegan <manzerberdes@gmx.com>2019-05-26 15:52:46 +0200
commitabe8eae55c5c51d0ce6626d243937e64f7ace51d (patch)
treef368a1a0756b3be25d5819cca6b3203b4f6634ab /src
parent5e3c82d06e7fa558bd8806fc9938271705280631 (diff)
Update simulator
Diffstat (limited to 'src')
-rwxr-xr-xsrc/ns3/g5k-root.sh14
-rwxr-xr-xsrc/ns3/g5k-worker.sh2
-rw-r--r--src/ns3/nix/simulator/main.cc2
-rw-r--r--src/ns3/simulate.org2
-rwxr-xr-xsrc/ns3/simulator/simulatorbin1172624 -> 1172624 bytes
5 files changed, 6 insertions, 14 deletions
diff --git a/src/ns3/g5k-root.sh b/src/ns3/g5k-root.sh
index 92903ee..332558c 100755
--- a/src/ns3/g5k-root.sh
+++ b/src/ns3/g5k-root.sh
@@ -12,7 +12,6 @@ logsFinalDst=~/logs/
[ "$1" == "subscribe" ] && subscribe=1 ||subscribe=0
[ "$1" == "deploy" ] && deploy=1 || deploy=0
[ "$1" == "-p" ] && progress=1 || progress=0
-[ "$1" == "scan" ] && scan=1 || scan=0
handleSim () {
[ -z "${argId}" ] && argId=1 || argId=$(( argId + 1 ))
@@ -66,7 +65,7 @@ then
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${NS3_PATH}/build/lib
# Default Parameters
- sensorsSendInterval=1 # DON'T GO BELOW 1 SECONDS !!!!!!! Simulator will stay stuck
+ sensorsSendInterval=10 # DON'T GO BELOW 1 SECONDS !!!!!!! Simulator will stay stuck
sensorsPktSize=192 # 1 byte temperature (-128 à +128 °C) and 4Byte sensorsId
sensorsNumber=5
nbHop=10 # Cf paper AC/Yunbo
@@ -120,7 +119,7 @@ then
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${NS3_PATH}/build/lib
# Default Parameters
- sensorsSendInterval=1 # DON'T GO BELOW 1 SECONDS !!!!!!! Simulator will stay stuck
+ sensorsSendInterval=10 # DON'T GO BELOW 1 SECONDS !!!!!!! Simulator will stay stuck
sensorsPktSize=192 # 1 byte temperature (-128 à +128 °C) and 4Byte sensorsId
sensorsNumber=5
nbHop=10 # Cf paper AC/Yunbo
@@ -177,7 +176,7 @@ then
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${NS3_PATH}/build/lib
# Default Parameters
- sensorsSendInterval=1 # DON'T GO BELOW 1 SECONDS !!!!!!! Simulator will stay stuck
+ sensorsSendInterval=10 # DON'T GO BELOW 1 SECONDS !!!!!!! Simulator will stay stuck
sensorsPktSize=192 # 1 byte temperature (-128 à +128 °C) and 4Byte sensorsId
sensorsNumber=5
nbHop=10 # Cf paper AC/Yunbo
@@ -254,13 +253,6 @@ then
alreadyFinished=$(cat $finishedFile| tail -n +2| wc -l)
percent=$(echo $alreadyFinished $nHost| awk '{print $1/$2*100}')
echo "Progression: " $alreadyFinished/$nHost "(${percent}%)"
-elif [ $scan -eq 1 ]
-then
- for host in $(cat $OAR_NODE_FILE|uniq)
- do
- proc=$(oarsh $host "ps -e|grep -i simulator")
- [ ! -z "$proc" ] && { echo "- Processes for node $host:"; echo "$proc"; }
- done
else
echo "Invalid arguments, make sure you know what you are doing !"
exit 1
diff --git a/src/ns3/g5k-worker.sh b/src/ns3/g5k-worker.sh
index 402a1a5..4803819 100755
--- a/src/ns3/g5k-worker.sh
+++ b/src/ns3/g5k-worker.sh
@@ -21,7 +21,7 @@ do
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${NS3_PATH}/build/lib
# Default Parameters
- sensorsSendInterval=1 # DON'T GO BELOW 1 SECONDS !!!!!!! Simulator will stay stuck
+ sensorsSendInterval=10 # DON'T GO BELOW 1 SECONDS !!!!!!! Simulator will stay stuck
sensorsPktSize=192 # 1 byte temperature (-128 à +128 °C) and 4Byte sensorsId
sensorsNumber=5
nbHop=10 # Cf paper AC/Yunbo
diff --git a/src/ns3/simulate.org b/src/ns3/simulate.org
index b6674d4..88b69b1 100644
--- a/src/ns3/simulate.org
+++ b/src/ns3/simulate.org
@@ -115,7 +115,7 @@
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${NS3_PATH}/build/lib
# Default Parameters
- sensorsSendInterval=1 # DON'T GO BELOW 1 SECONDS !!!!!!! Simulator will stay stuck
+ sensorsSendInterval=10 # DON'T GO BELOW 1 SECONDS !!!!!!! Simulator will stay stuck
sensorsPktSize=192 # 1 byte temperature (-128 à +128 °C) and 4Byte sensorsId
sensorsNumber=5
nbHop=10 # Cf paper AC/Yunbo
diff --git a/src/ns3/simulator/simulator b/src/ns3/simulator/simulator
index 06e6322..297bd5b 100755
--- a/src/ns3/simulator/simulator
+++ b/src/ns3/simulator/simulator
Binary files differ
diff --git a/src/ns3/nix/simulator/main.cc b/src/ns3/nix/simulator/main.cc
index 8857414..a8ec8cf 100644
--- a/src/ns3/nix/simulator/main.cc
+++ b/src/ns3/nix/simulator/main.cc
@@ -11,7 +11,7 @@ NS_LOG_COMPONENT_DEFINE ("WIFISensorsSimulator");
*/
int main(int argc, char* argv[]){
- uint32_t sensorsFrequency=1; // One pkt every second
+ uint32_t sensorsFrequency=10; // 1 pkt every 10 seconds
uint32_t sensorsPktSize=192; // 128 bits for sensors id and 32 bit for the temperature (an arbitrary Integer) and a timestamp (32bits)
uint32_t sensorsNumber=5;
uint32_t nbHop=10;